@@ -12,7 +12,7 @@
 # License; see this file: https://github.com/RDFLib/rdflib/blob/master/LICENSE
 
 from xmptools.xmptools import makeFileURI, isContainerItemPredicate, makeContainerItemPredicate
-from xmptools.xmptools import cbd, identity
+from xmptools.xmptools import getContainerStatements, cbd, identity, makeFileURI, makeFilePath
 from xmptools.xmptools import XMPMetadata
 from xmptools.xmptools import DC, DCT, XMP, EXIF, CRS, PHOTOSHOP
 from xmptools.xmptools import JPEG_EXTENSIONS, TIFF_EXTENSIONS, RAW_EXTENSIONS, DNG_EXTENSIONS
@@ -21,7 +21,7 @@ from xmptools.xmptools import FileTypeError, XMPParser, XMPSerializer
 
 __all__ = [
     'makeFileURI', 'isContainerItemPredicate', 'makeContainerItemPredicate',
-    'cbd', 'identity',
+    'getContainerStatements', 'cbd', 'identity', 'makeFileURI', 'makeFilePath',
     'XMPMetadata',
     'DC', 'DCT', 'XMP', 'EXIF', 'CRS', 'PHOTOSHOP',
     'JPEG_EXTENSIONS', 'TIFF_EXTENSIONS', 'RAW_EXTENSIONS', 'DNG_EXTENSIONS',
