@@ -148,6 +148,10 @@ class MoreThanOneValue(Error):
     pass
 
 
+class DataNotFound(Error):
+    pass
+
+
 def URI(u):
     return u if isinstance(u, URIRef) or u is None else URIRef(u)
 
@@ -168,8 +172,9 @@ def getContainerStatements(graph, source, predicate):
     containers = list(graph.objects(URI(source), predicate))
     n = len(containers)
     if n == 1:
-        statements = graph.triples((containers[0], None, None))
-        return [statement for statement in statements if isContainerItemPredicate(statement[1])]
+        return sorted([statement for statement in graph.triples((containers[0], None, None))
+                       if isContainerItemPredicate(statement[1])],
+                      key=lambda tr: tr[1])
     elif n == 0:
         return None
     else:
@@ -378,7 +383,7 @@ class XMPMetadata(Graph):
             # If destination is specified, it must be a pathname ending in ".xmp", or a stream
             if isinstance(destination, str):
                 if not destination.endswith(".xmp"):
-                    raise ValueError("Only XMP files can be written, not " + destination)
+                    raise FileTypeError("Only XMP files can be written, not {0}", destination)
             elif not isinstance(destination, io.IOBase):
                 raise ValueError("Unsupported destination: " + destination)
         elif not self.sourceIsXMP:
@@ -400,14 +405,24 @@ class XMPMetadata(Graph):
         value = self.getValue(predicate)
         if value:
             date_candidate = value.value
-            return self.iso8601.parse(date_candidate) if isinstance(date_candidate,
-                                                                    str) else date_candidate
+            return (self.iso8601.parse(date_candidate)
+                    if isinstance(date_candidate, str) else date_candidate)
         else:
             return None
 
     def setDate(self, timestamp=datetime.utcnow(), predicate=XMP.MetadataDate):
         self.set((self.url, predicate, Literal(timestamp)))
 
+    def findDateCreated(self, predicates=None, error=DataNotFound):
+        for p in predicates or [XMP.CreateDate, EXIF.DateTimeOriginal, PHOTOSHOP.DateCreated]:
+            dt = self.getDate(p)
+            if dt:
+                return dt, p
+        if error:
+            raise error("Date not found")
+        else:
+            return None, None
+
     def getContainerItems(self, predicate):
         statements = getContainerStatements(self, self.url, predicate)
         return [statement[2] for statement in statements] if statements else None
@@ -436,25 +451,34 @@ class XMPMetadata(Graph):
             self.remove((container, None, None))
 
     def container2repeated(self, predicate,
-                           new_predicate=None, value_mapper=identity):
+                           new_predicate=None, value_mapper=identity, remove_predicate=False,
+                           target_graph=None):
         # We understand that this messes with ordering
         if new_predicate is None:
             new_predicate = predicate
+        if target_graph is None:
+            target_graph = self
         items = self.getContainerItems(predicate)
         if items:
-            self.setContainerItems(predicate, [])
+            if remove_predicate:
+                self.setContainerItems(predicate, [])
             for item in items:
-                self.add((self.url, new_predicate, value_mapper(item)))
+                target_graph.add((self.url, new_predicate, value_mapper(item)))
+        return target_graph
 
     def repeated2container(self, predicate,
-                           new_predicate=None, newtype=RDF.Seq, value_mapper=identity):
+                           new_predicate=None, newtype=RDF.Seq, value_mapper=identity,
+                           remove_predicate=False, source_graph=None):
         # We understand that this messes with ordering
         if new_predicate is None:
             new_predicate = predicate
-        statements = self.triples((self.url, predicate, None))
+        if source_graph is None:
+            source_graph = self
+        statements = source_graph.triples((self.url, predicate, None))
         if statements:
-            for statement in statements:
-                self.remove(statement)
+            if remove_predicate:
+                for statement in statements:
+                    self.remove(statement)
             self.setContainerItems(new_predicate, [value_mapper(o) for _, _, o in statements],
                                    newtype=newtype)
 
